aboutsummaryrefslogtreecommitdiff
path: root/tw
diff options
context:
space:
mode:
authorTimo Wilken2024-07-12 22:05:28 +0200
committerTimo Wilken2024-07-12 22:05:28 +0200
commitc52346c9b3a667cfee5e833ce295d2c7a519893a (patch)
tree7f93896240f0285fd7ac2101d36fa04dfbba1315 /tw
parent045e8e2a0c9922a0ca8d717efa507b295204607e (diff)
Use Wayland desktop on Framework desktop
Diffstat (limited to 'tw')
-rw-r--r--tw/home/frm.scm23
-rw-r--r--tw/services/files/sway.conf5
-rw-r--r--tw/system/frm.scm9
3 files changed, 13 insertions, 24 deletions
diff --git a/tw/home/frm.scm b/tw/home/frm.scm
index 27b0ccbb..90975f20 100644
--- a/tw/home/frm.scm
+++ b/tw/home/frm.scm
@@ -36,30 +36,13 @@
(home-batsignal-configuration
(batteries '("BAT1"))))
- ;; Redshift: make the screen turn redder at night.
- (service home-redshift-service-type
- (home-redshift-configuration
- (location-provider 'manual)
- ;; Approximate location
- (latitude 46.0)
- (longitude 6.0)
- ;; (location-provider 'geoclue2) ; TODO: currently waits forever for a location -- not sure why geoclue doesn't work
- (daytime-brightness 1.0)
- (nighttime-brightness 0.7)
- (extra-content "fade=0"))) ; with fade=1, restarting redshift causes flickering for a few secs
-
(service home-dbus-service-type)
(service tw-home-service-type)
- (service home-desktop-service-type
- (home-desktop-configuration
- (battery-name "BAT1")
- (ac-adapter-name "ACAD")
- (monitors
- (list (home-monitor-configuration
- (name "eDP")
- (xrandr-options '("--auto")))))))
+ (service home-wayland-desktop-service-type
+ (home-wayland-desktop-configuration
+ (num-cores 12)))
(service home-full-dev-env-service-type)
diff --git a/tw/services/files/sway.conf b/tw/services/files/sway.conf
index 353c8c6a..1b0ccfb7 100644
--- a/tw/services/files/sway.conf
+++ b/tw/services/files/sway.conf
@@ -36,6 +36,11 @@ client.background $c_bg
# }}}
# Output Configuration {{{
+## Framework laptop
+# Laptop screen
+output "BOE 0x0BCA Unknown" scale 1.5
+
+## Work laptop
# Laptop screen
output "AU Optronics 0x4CA3 Unknown" position 0 0
# Displays at work
diff --git a/tw/system/frm.scm b/tw/system/frm.scm
index c05b7180..07e77cbc 100644
--- a/tw/system/frm.scm
+++ b/tw/system/frm.scm
@@ -65,7 +65,7 @@
;; The MT7921E module is for the card connected via PCIe, which it is
;; (it's in an M.2 slot). Alternatives are S (SDIO) and U (USB).
(kernel (nongnu:corrupt-linux linux-libre #:configs '("CONFIG_MT7921E=m")))
- ;; (kernel-loadable-modules (list ddcci-driver-linux)) ; TODO: disabled because the package fails to build
+ (kernel-loadable-modules (list ddcci-driver-linux v4l2loopback-linux-module))
;; Fix screen flashing white: https://community.frame.work/t/39073
(kernel-arguments (cons* "amdgpu.sg_display=0" %default-kernel-arguments))
(initrd nongnu:microcode-initrd)
@@ -108,10 +108,10 @@
(sudoers-file
(plain-file "sudoers"
(string-append
;; We need to preserve $TERMINFO so that programs under sudo can
;; find kitty's terminfo files. This is possibly unsafe; sudo
;; explicitly deletes this variable by default.
- "Defaults env_keep += \"TERMINFO\"\n"
+ "Defaults env_keep += \"TERMINFO_DIRS\"\n"
(plain-file-content %sudoers-specification)
;; In addition to the default rules, allow admins to power off
;; the computer. They'll have to use the system binaries, not
@@ -163,6 +163,7 @@
(modify-services (enduser-system-services
#:host-name host-name
#:cores 12
+ #:wayland? #t
#:wireless-interface "wlp1s0"
#:backlight-device "amdgpu_bl0")
(delete thermald-service-type))))))
@@ -108,10 +108,10 @@
(plain-file "sudoers"
(string-append
- ;; We need to preserve $TERMINFO so that programs under sudo can
- ;; find kitty's terminfo files. This is possibly unsafe; sudo
+ ;; We need to preserve $TERMINFO_DIRS so that programs under sudo can
+ ;; find foot's terminfo files. This is possibly unsafe; sudo
;; explicitly deletes this variable by default.